@@ -1,22 +1,26 @@
 package CGI::Kwiki::Changes;
-$VERSION = '0.10';
+$VERSION = '0.14';
 use strict;
 use base 'CGI::Kwiki';
 
 sub process {
     my ($self) = @_;
+    $self->driver->load_class('metadata');
     my $search = $self->cgi->page_id;
     return
-      $self->template->header .
+      $self->template->process(
+          'display_header',
+          $self->template->display_vars,
+      ) .
       $self->changes .
-      $self->template->footer;
+      $self->template->process('basic_footer');
 }
 
 sub changes {
     my ($self) = @_;
     my $search = $self->cgi->search;
     my $pages = [ map {[$_, -M $_]} glob "database/*" ];
-    my $html = '';
+    my $html = qq{<table border="0">\n};
     for my $range
         (["hour", 1/24],
          ["3 hours", 0.125],
@@ -35,11 +39,15 @@ sub changes {
           for @$pages;
         $pages = $older;
         if (@$recent) {
-            $html .= "<h2>Changes in the last $range->[0]:</h2>\n";
+            $html .= qq{<tr><td colspan="3"><h2>Changes in the last $range->[0]:</h2>\n};
             for my $page_id (sort {-M $a <=> -M $b} 
                              map {$_->[0]} @$recent) {
+                $html .= "<tr>\n";
                 $page_id =~ s/.*[\/\\](.*)/$1/;
-                $html .= qq{<a href="?$page_id">$page_id</a><br>\n};
+                my $metadata = $self->driver->metadata->get($page_id);
+                my $edit_by = $metadata->{edit_by} || '&nbsp';
+                $html .= qq{<td><a href="?$page_id">$page_id</a>\n};
+                $html .= qq{<td>&nbsp;<td>$edit_by\n};
             }
         }
     }
@@ -48,6 +56,8 @@ sub changes {
 
 1;
 
+__END__
+
 =head1 NAME 
 
 CGI::Kwiki::Changes - Changes Base Class for CGI::Kwiki
