@@ -2,11 +2,28 @@ package CGI::Kwiki::Edit;
 $VERSION = '0.14';
 use strict;
 use base 'CGI::Kwiki';
+use CGI::Kwiki ':char_classes';
+
+use constant NEW_DEFAULT => '- New Page Name -';
+
+my $error_msg;
 
 sub process {
     my ($self) = @_;
-    return $self->save 
-      if $self->cgi->button =~ /^save$/i;
+    $error_msg = '';
+    $self->cgi->page_id_new($self->cgi->page_id_new || NEW_DEFAULT);
+    my $page_id_new = $self->cgi->page_id_new;
+    if (length $page_id_new and
+        $page_id_new ne NEW_DEFAULT and
+        $page_id_new !~ /^[$ALPHANUM\:\-]+$/
+       ) {
+        $error_msg = 
+          qq{<font color="red">Invalid page name '$page_id_new'</font>};
+    }
+    else {
+        return $self->save 
+          if $self->cgi->button =~ /^save$/i;
+    }
     return $self->preview 
       if $self->cgi->button =~ /^preview$/i;
     my $wiki_text = $self->driver->database->load;
@@ -15,7 +32,8 @@ sub process {
           $self->template->display_vars,
       ) .
       $self->template->process('edit_body', 
-           wiki_text => $wiki_text
+          wiki_text => $wiki_text,
+          error_msg => $error_msg,
       ) .
       $self->template->process('basic_footer');
 }
@@ -29,15 +47,23 @@ sub preview {
       $self->template->process('display_header',
           $self->template->display_vars,
       ) .
-      $self->template->process('edit_body') .
+      $self->template->process('edit_body',
+          error_msg => $error_msg,
+      ) .
       $self->template->process('preview_body',
-          preview => $preview
+          preview => $preview,
       ) .
       $self->template->process('basic_footer');
 }
 
 sub save {
     my ($self) = @_;
+    my $page_id_new = $self->cgi->page_id_new;
+    if (length $page_id_new and
+        $page_id_new ne NEW_DEFAULT
+       ) {
+        $self->cgi->page_id($page_id_new);
+    }
     my $wiki_text = $self->cgi->wiki_text;
     $self->driver->database->store($wiki_text);
     return { redirect => "index.cgi?" . $self->cgi->page_id };
